Method: Hanami::CLI::Command#initialize
- Defined in:
- lib/hanami/cli/command.rb
#initialize(out:, err:, fs:) ⇒ Command
Returns a new command.
This method does not need to be called directly when creating commands for the CLI. Commands are registered as classes, and the CLI framework will initialize the command when needed. This means that all parameters for #initialize should also be given default arguments. See new for the standard default arguments for all commands.
48 49 50 51 52 53 |
# File 'lib/hanami/cli/command.rb', line 48 def initialize(out:, err:, fs:) super() @out = out @err = err @fs = fs end |